use clap::Subcommand;
use game::GameCommand;

use crate::error::CmdResult;

mod game;
mod pack;

#[derive(Subcommand)]
pub enum Command {
	Game {
		#[command(flatten)]
		args: game::GameCommand,
	},

	Pack {
		#[command(flatten)]
		args: pack::PackCommand,
	},
}

impl Default for Command {
	fn default() -> Self {
		Self::Game {
			args: GameCommand::default(),
		}
	}
}

impl Command {
	pub fn run(self) -> CmdResult<()> {
		match self {
			Self::Pack { args } => args.run()?,
			Self::Game { args } => args.run()?,
		}

		return Ok(());
	}
}
