//! High-level errors thrown by subcommands.

use thiserror::Error;
use tracing::error;

pub type CmdResult<T> = Result<T, CmdError>;

#[derive(Debug, Error)]
pub enum CmdError {
	/// A generic I/O error
	#[error("I/O error")]
	IoError {
		#[from]
		error: std::io::Error,
	},

	/// A generic error message
	#[error("{msg}")]
	Generic { msg: String },
}

impl CmdError {
	pub fn log(&self) {
		match self {
			Self::IoError { error } => {
				error!("I/O Error: {}", error)
			}

			e => {
				error!("{}", e)
			}
		}
	}
}
