use clap::{ArgAction, Parser};
use logging::LoggingPreset;
use tracing::info;

mod cmd;
mod error;
mod logging;

/// Redox build utilities
#[derive(Parser)]
#[command(version, about, long_about = None)]
struct Cli {
	#[command(subcommand)]
	command: Option<cmd::Command>,

	/// Log more information. This flag can be repeated.
	#[arg(short = 'v', global = true, action = ArgAction::Count)]
	verbose: Option<u8>,

	/// Log less information. This flag counteracts `-v`, and can be repeated.
	#[arg(short = 'q', global = true, action = ArgAction::Count)]
	quiet: Option<u8>,
}

fn main() {
	let cli = Cli::parse();

	{
		let verbose: i32 = cli.verbose.unwrap_or(0).into();
		let quiet: i32 = cli.quiet.unwrap_or(0).into();
		let preset = LoggingPreset::from_number(verbose - quiet);

		tracing_subscriber::fmt()
			.with_env_filter(preset.get_config())
			.without_time()
			.with_ansi(true)
			.init();
	};

	match cli.command.unwrap_or_default().run() {
		Ok(()) => {
			info!(message = "Exiting normally");
		}
		Err(e) => {
			e.log();
			std::process::exit(1);
		}
	};
}
