use thiserror::Error;
use tracing::error;

pub type ContentLoadResult<T> = Result<T, ContentLoadError>;

#[derive(Debug, Error)]
pub enum ContentLoadError {
	/// A generic I/O error
	#[error("I/O error: {error}")]
	IoError {
		#[from]
		error: std::io::Error,
	},

	/// Toml deserialization error
	#[error("TOML deserialization error: {error}")]
	TomlError {
		#[from]
		error: toml::de::Error,
	},

	#[error("Content dir has multiple config tables")]
	MultipleConfigTables,

	#[error("Content dir does not have a config table")]
	MissingConfigTable,

	#[error("Content dir has duplicate key `{key}`")]
	DuplicateKey { key: String },

	#[error("{msg}")]
	Generic { msg: String },

	#[error("error while compiling rhai script: {error}")]
	RhaiCompileError {
		#[from]
		error: Box<rhai::EvalAltResult>,
	},
}
