use std::fmt::Debug;

use crate::stateframe::{PhysSimShipHandle, SystemStateframe};

mod null;
mod point;

pub use null::NullShipAgent;
pub use point::PointShipAgent;

/// A ship's controls
#[derive(Debug, Clone)]
pub struct ShipControls {
	/// True if turning left
	pub left: bool,

	/// True if turning right
	pub right: bool,

	/// True if foward thrust
	pub thrust: bool,

	/// True if firing guns
	pub guns: bool,

	/// If set, land on the given object if possible.
	pub landing: bool,
}

impl ShipControls {
	/// Create a new, empty ShipControls
	pub fn new() -> Self {
		ShipControls {
			left: false,
			right: false,
			thrust: false,
			guns: false,
			landing: false,
		}
	}
}

pub trait ShipAgent
where
	Self: Debug,
{
	/// Update a ship's controls based on system state.
	/// This method returns the ship's new control values,
	/// or None if no change is to be made.
	fn update_controls(
		&mut self,
		dt: f32,
		sf: &SystemStateframe,
		this_ship: PhysSimShipHandle,
	) -> Option<ShipControls>;
}
